---
slug: /sysbench-benchmark-report-of-seekdb
---

# seekdb Sysbench benchmark report

This topic describes the test environment, test plan, and detailed test results of the Sysbench benchmark.

## Test plan

* In this test, two machines are required. Sysbench is deployed on one machine, and seekdb is deployed on the other. The specifications of seekdb are 4C8G or 1C2G. The seekdb instance is configured with three disks for logs, clogs, and data, respectively, and the performance level is PL1.

* Import 30 tables into seekdb. Each table contains 10,000 rows of data.

* Run the `point_select`, `read_write`, `read_only`, `insert`, `update`, and `write_only` tests on the Sysbench client.

* Set the `--time` parameter to 10s for each test round. The number of threads can be 10, 50, 100, 200, or 400.

For more information about the test steps, see [Test seekdb by using Sysbench](100.use-sysbench-to-test-the-performance-of-seekdb.md).

## Test environment

This example uses Alibaba Cloud ECS as the deployment environment. The seekdb instance used in the test has the 1C2G or 4C8G specification.

* If the seekdb instance has the 4C8G specification, the corresponding hardware configuration and software version are as follows:

    * Hardware configuration

        | Service type | ECS type | Number of instances | Number of CPU cores | Memory |
        | ------- | -------- | ----- | --------- | ---- |
        | seekdb | ecs.c8i.xlarge  | 1 | 4C | 8G |
        | Sysbench          | ecs.g8i.4xlarge   | 1 | 16C | 64G |

    * Software version

        | Service type | Software version |
        | ------- | ------- |
        | seekdb | SeekDB 1.0.0.0 |
        | Sysbench        | 1.1.0 |
        | OS              | CentOS Linux 7 (Core) |

* If the seekdb instance has the 1C2G specification, the corresponding hardware configuration and software version are as follows:

    * Hardware configuration

        | Service type | ECS type | Number of instances | Number of CPU cores | Memory |
        | ------- | -------- | ----- | --------- | ---- |
        | seekdb | ecs.c8i.large  | 1 | 2C (1 active vCPU) | 4G (3G available memory) |
        | Sysbench          | ecs.g8i.4xlarge   | 1 | 16C | 64G |

    * Software version

        | Service type | Software version |
        | ------- | ------- |
        | seekdb | SeekDB 1.0.0.0 |
        | Sysbench        | 1.1.0 |
        | OS              | CentOS Linux 7 (Core) |

## Test results

In this Sysbench benchmark, the performance of `point_select`, `read_write`, `read_only`, `insert`, `update`, and `write_only` is tested under 10, 50, 100, 200, and 400 threads.

:::info

The data in the table is tps/99rt. The data is based on pure memory, and no dump is performed during the seekdb write process.

:::

### Performance data

* If the seekdb instance has the 4C8G specification, the corresponding performance data is as follows:

    | Threads | point_select | read_only | read_write | insert | update | write_only |
    |---------|----------------------|----------------------|---------------|--------------|--------------|--------------|
    | 10   | 77328.66/0.23 | 3319.07/5.00 | 1882.00/7.30 | 10185.03/2.76 | 9314.96/6.67 | 4688.54/4.03 |
    | 50   | 100347.57/7.43 | 4020.60/31.37 | 2619.97/30.81 | 26437.48/3.43 | 29488.94/3.75 | 7543.28/10.84 |
    | 100  | 105079.01/9.22 | 4087.84/57.87 | 2674.02/73.13 | 33417.85/4.82 | 34507.15/5.47 | 9184.84/20.00 |
    | 200  | 106356.60/11.87 | 4066.73/99.33 | 2710.92/125.52 | 38261.34/8.43 | 42389.73/7.43 | 9874.32/36.24 |
    | 400  | 108138.11/15.00 | 4159.58/144.97 | 2856.73/200.47 | 41418.19/16.41 | 43852.58/14.73 | 10541.13/66.84 |

* If the seekdb instance has the 1C2G specification, the corresponding performance data is as follows:

    | Threads | point_select | read_only | read_write | insert | update | write_only |
    |---------|----------------------|----------------------|---------------|--------------|--------------|--------------|
    | 10   | 41347.53/0.53 | 1625.06/9.91 | 840.04/17.95 | 8587.38/2.52 | 8988.56/2.76 | 2959.13/5.57 |
    | 50   | 41462.17/1.86 | 1661.72/41.85 | 1059.56/62.19 | 14456.36/5.47 | 14894.71/5.37 | 4082.69/17.63 |
    | 100  | 42123.36/3.49 | 1758.03/71.83 | 1160.80/102.97 | 16099.96/23.52 | 17200.51/8.90 | 4325.64/31.94 |
    | 200  | 41858.17/7.04 | 1764.61/130.13 | 1192.46/204.11 | 17474.96/17.0 | 18839.09/75.82 | 4453.70/78.60 |